@@ -17,6 +17,19 @@ using Mdual = Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>;
 template <typename T>
 using ldlt = Eigen::SimplicialLDLT<Eigen::SparseMatrix<T> >;
 
+//' @name Model
+//' @title Encapsulates a model
+//' @description The members of this virtual class are different generalized
+//'   linear models.
+//' @field new Constructor.
+//' @field cumulant Cumulant function of the model family.
+//' @field constfun Constant term in log-likelihood of the model family.
+//' @field meanfun Expected value of the response at the given parameters.
+//' @field get_V Extract diagonal matrix whose elements are
+//'   \eqn{\eqn{b''(\nu_{i}) / \phi_{g(i)}}}.
+//' @field get_phi Extract dispersion parameter.
+//' @srrstats {G1.4a} Internal class documented.
+//' @noRd
 template <typename T>
 struct Model {
   Model() {};
@@ -31,8 +44,24 @@ struct Model {
                     const Vdual<T>& y, const Ddual<T>& WSqrt, int n) = 0;
 };
 
+//' @name Binomial
+//' @title Member functions for binomial responses
+//' @field new Constructor, which takes the constant term \code{k} as argument.
+//' @field cumulant Cumulant function for logistic regression.
+//' @field constfun Constant term in log-likelihood for logistic regression.
+//' @field meanfun Expected value of the response at the given parameters.
+//'   Includes the number of trials, so it does NOT return a proportion.
+//' @field get_V Extract diagonal matrix whose elements are
+//'   \eqn{\eqn{b''(\nu_{i}) / \phi_{g(i)}}}. Since \eqn{\phi = 1}, what we
+//'   extract here is the binomial variance function. A comment to the
+//'   implementation: since \code{meanfun} returns the number of expected
+//'   successes, \eqn{\mu(\eta) = N \exp(\eta) / (1 + \exp(\eta))}, and hence
+//'   \eqn{\mu'(\eta) = d''(\eta) = \mu(\eta) * (N - \mu(\eta)) / N}.
+//' @field get_phi Extract dispersion parameter, which in this case equals 1.
+//' @srrstats {G1.4a} Internal class documented.
+//' @noRd
 template <typename T>
-struct Binomial : Model<T> {
+struct Binomial final : Model<T> {
   Binomial(double k) : k { static_cast<T>(k) } {}
   T k;
   T cumulant(const Vdual<T>& linpred, const Vdual<T>& trials,
@@ -48,11 +77,6 @@ struct Binomial : Model<T> {
     return linpred.array().exp() / (1 + linpred.array().exp()) * trials.array();
   };
 
-  // Binomial variance function
-  // meanfun() includes the number of trials, and hence returns the number of
-  // expected successes, and not the expected proportion of successes.
-  // Thus, mu(eta) = N * exp(eta) / (1 + exp(eta)) and
-  // m'(eta) = d''(eta) = mu * (N - mu) / N.
   Vdual<T> get_V(
       const Vdual<T>& linpred, const Vdual<T>& trials,
       const Ddual<T>& WSqrt) override {
@@ -67,8 +91,20 @@ struct Binomial : Model<T> {
   };
 };
 
+//' @name Gaussian
+//' @title Member functions for Gaussian responses
+//' @field new Constructor is inherited from the \code{Model} class, and does
+//'   nothing.
+//' @field cumulant Cumulant function for linear regression.
+//' @field constfun Constant term in log-likelihood for linear regression.
+//' @field meanfun Expected value of the response at the given parameters.
+//' @field get_V Extract diagonal matrix whose elements are
+//'   \eqn{\eqn{b''(\nu_{i}) / \phi_{g(i)}}}.
+//' @field get_phi Extract dispersion parameter.
+//' @srrstats {G1.4a} Internal class documented.
+//' @noRd
 template <typename T>
-struct Gaussian : Model<T> {
+struct Gaussian final : Model<T> {
 
   T cumulant(const Vdual<T>& linpred, const Vdual<T>& trials,
              const Ddual<T>& WSqrt) override {
@@ -83,7 +119,6 @@ struct Gaussian : Model<T> {
     return linpred;
   };
 
-  // How to update diagonal variance matrix is model dependent
   Vdual<T> get_V(const Vdual<T>& linpred, const Vdual<T>& trials,
                  const Ddual<T>& WSqrt) override {
         return WSqrt.diagonal().array().pow(2);
@@ -98,8 +133,19 @@ struct Gaussian : Model<T> {
 
 };
 
+//' @name Poisson
+//' @title Member functions for Poisson responses
+//' @field new Constructor, which takes the constant term \code{k} as argument.
+//' @field cumulant Cumulant function for Poisson regression.
+//' @field constfun Constant term in log-likelihood for Poisson regression.
+//' @field meanfun Expected value of the response at the given parameters.
+//' @field get_V Extract diagonal matrix whose elements are
+//'   \eqn{\eqn{b''(\nu_{i}) / \phi_{g(i)}}}.
+//' @field get_phi Extract dispersion parameter, which in this case equals 1.
+//' @srrstats {G1.4a} Internal class documented.
+//' @noRd
 template <typename T>
-struct Poisson : Model<T> {
+struct Poisson final : Model<T> {
   Poisson(double k) : k {static_cast<T>(k)} {}
   T k;
   T cumulant(const Vdual<T>& linpred, const Vdual<T>& trials,
@@ -113,7 +159,6 @@ struct Poisson : Model<T> {
     return linpred.array().exp();
   };
 
-  // How to update diagonal variance matrix is model dependent
   Vdual<T> get_V(
       const Vdual<T>& linpred, const Vdual<T>& trials, const Ddual<T>& WSqrt) override {
         return meanfun(linpred, trials).array();
